@@ -27,12 +27,13 @@ from libcloud.compute.base import NodeImage
 from libcloud.compute.deployment import MultiStepDeployment
 from libcloud.compute.deployment import ScriptDeployment, SSHKeyDeployment
 from libcloud.compute.providers import get_driver
-from libcloud.compute.types import Provider, DeploymentException
+from libcloud.compute.types import DeploymentException
 from libcloud.compute.types import KeyPairDoesNotExistError
 
 import fedimg
 import fedimg.messenger
 from fedimg.util import get_file_arch, get_virt_type, ssh_connection_works
+from fedimg.util import region_to_provider
 
 
 class EC2ServiceException(Exception):
@@ -59,25 +60,29 @@ class EC2Service(object):
         self.util_volume = None
         self.snapshot = None
         self.image = None
+        self.image_desc = None
         self.test_node = None
         self.build_name = 'Fedimg build'
         self.destination = 'somewhere'
         self.test_success = False
+        self.dup_count = 0  # counter: helps avoid duplicate AMI names
+        self.amis = list()  # Will contain dicts. Dicts will contain AMI info.
 
-        # Will be a list of dicts. Dicts will contain AMI info.
-        self.amis = list()
-
+        # Populate list of AMIs by reading the AMI details from the config
+        # file.
         for line in fedimg.AWS_AMIS.split('\n'):
-            """ Each line in AWS_AMIS has pipe-delimited attributes at these indicies:
+            """ AWS_AMIS lines have pipe-delimited attrs at these indicies:
             0: region (ex. eu-west-1)
             1: OS (ex. RHEL)
             2: version (ex. 5.7)
             3: arch (ex. x86_64)
             4: ami name (ex. ami-68e3d32d) """
+
             # strip line to avoid any newlines or spaces from sneaking in
             attrs = line.strip().split('|')
+
             info = {'region': attrs[0],
-                    'prov': self._region_to_provider(attrs[0]),
+                    'prov': region_to_provider(attrs[0]),
                     'os': attrs[1],
                     'ver': attrs[2],
                     'arch': attrs[3],
@@ -85,19 +90,6 @@ class EC2Service(object):
                     'aki': attrs[5]}
             self.amis.append(info)
 
-    def _region_to_provider(self, region):
-        """ Takes a region name (ex. 'eu-west-1') and returns
-        the appropriate libcloud provider value. """
-        providers = {'ap-northeast-1': Provider.EC2_AP_NORTHEAST,
-                     'ap-southeast-1': Provider.EC2_AP_SOUTHEAST,
-                     'ap-southeast-2': Provider.EC2_AP_SOUTHEAST2,
-                     'eu-west-1': Provider.EC2_EU_WEST,
-                     'sa-east-1': Provider.EC2_SA_EAST,
-                     'us-east-1': Provider.EC2_US_EAST,
-                     'us-west-1': Provider.EC2_US_WEST,
-                     'us-west-2': Provider.EC2_US_WEST_OREGON}
-        return providers[region]
-
     def _clean_up(self, driver, delete_image=False):
         """ Cleans up resources via a libcloud driver. """
         logging.info('Cleaning up resources')
@@ -137,6 +129,7 @@ class EC2Service(object):
         try:
             file_name = raw_url.split('/')[-1]
             self.build_name = file_name.replace('.raw.xz', '')
+            self.image_desc = "Created from build {0}".format(self.build_name)
             image_arch = get_file_arch(file_name)
             # no EBS-enabled instance types offer a 32 bit architecture
             self.amis = [a for a in self.amis if a['arch'] == 'x86_64']
@@ -328,18 +321,17 @@ class EC2Service(object):
 
             # Avoid duplicate image name by incrementing the number at the
             # end of the image name if there is already an AMI with that name.
-            dup_count = 0  # counter: number of AMIs with same base image name
             while True:
                 try:
-                    if dup_count > 0:
+                    if self.dup_count > 0:
                         # Remove trailing '-0' or '-1' or '-2' or...
                         image_name = '-'.join(image_name.split('-')[:-1])
                         # Re-add trailing dup number with new count
-                        image_name += '-{0}'.format(dup_count)
+                        image_name += '-{0}'.format(self.dup_count)
                     # Try to register with that name
                     self.image = driver.ex_register_image(
                         image_name,
-                        description=None,
+                        description=self.image_desc,
                         root_device_name=reg_root_device_name,
                         block_device_mapping=mapping,
                         virtualization_type=virt_type,
@@ -349,7 +341,7 @@ class EC2Service(object):
                     # Check if the problem was a duplicate name
                     if 'InvalidAMIName.Duplicate' in e.message:
                         # Keep trying until an unused name is found
-                        dup_count += 1
+                        self.dup_count += 1
                         continue
                     else:
                         raise
@@ -359,7 +351,8 @@ class EC2Service(object):
 
             # Emit success fedmsg
             fedimg.messenger.message('image.upload', self.build_name,
-                                     self.destination, 'completed')
+                                     self.destination, 'completed',
+                                     extra={'id': self.image.id})
 
             # Spin up a node of the AMI to test
 
@@ -419,7 +412,8 @@ class EC2Service(object):
 
             logging.info('AMI test completed')
             fedimg.messenger.message('image.test', self.build_name,
-                                     self.destination, 'completed')
+                                     self.destination, 'completed',
+                                     extra={'id': self.image.id})
             self.test_success = True
 
             logging.info('Destroying test node')
@@ -493,19 +487,19 @@ class EC2Service(object):
                 # Avoid duplicate image name by incrementing the number at the
                 # end of the image name if there is already an AMI with
                 # that name.
-                dup_count = 0  # counter: num of AMIs with same base image name
                 while True:
                     try:
-                        if dup_count > 0:
+                        if self.dup_count > 0:
                             # Remove trailing '-0' or '-1' or '-2' or...
                             image_name = '-'.join(image_name.split('-')[:-1])
                             # Re-add trailing dup number with new count
-                            image_name += '-{0}'.format(dup_count)
+                            image_name += '-{0}'.format(self.dup_count)
 
                         image_copy = alt_driver.copy_image(
                             self.image,
                             self.amis[0]['region'],
-                            name=image_name)
+                            name=image_name,
+                            description=self.image_desc)
 
                         copied_images.append(image_copy)
 
@@ -514,8 +508,12 @@ class EC2Service(object):
                     except Exception as e:
                         # Check if the problem was a duplicate name
                         if 'InvalidAMIName.Duplicate' in e.message:
-                            # Keep trying until an unused name is found
-                            dup_count += 1
+                            # Keep trying until an unused name is found.
+                            # This probably won't trigger, since it seems
+                            # like EC2 doesn't mind duplicate AMI names
+                            # when they are being copied, only registered.
+                            # Strange, but true.
+                            self.dup_count += 1
                             continue
                         else:
                             # TODO: Catch a more specific exception
@@ -544,13 +542,15 @@ class EC2Service(object):
                             {'LaunchPermission.Add.1.Group': 'all'})
                     except Exception as e:
                         if 'InvalidAMIID.Unavailable' in e.message:
+                            # Copy isn't done, so wait 20 seconds and try
+                            # again.
                             sleep(20)
                             continue
                     break
 
-                # TODO: Add logging here
-                logging.info('Made image {0} public'.format(image))
+                logging.info('Made image {0} public'.format(image.name))
 
                 fedimg.messenger.message('image.upload',
                                          self.build_name,
-                                         alt_dest, 'completed')
+                                         alt_dest, 'completed',
+                                         extra={'id': image.id})
